@@ -1,4 +1,4 @@
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional
 
 import h5py
 import ipyvolume as ipv
@@ -22,6 +22,8 @@ from popsynth.utils.hdf5_utils import (
 from popsynth.utils.logging import setup_logger
 from popsynth.utils.spherical_geometry import xyz
 
+from .simulated_variable import SimulatedVariable
+
 log = setup_logger(__name__)
 
 wine = "#8F2727"
@@ -55,6 +57,7 @@ class Population(object):
         theta=None,
         phi=None,
         pop_synth: Optional[Dict[str, Any]] = None,
+        probability: Optional[np.ndarray] = None,
     ) -> None:
         """
         A population container for all the properties of the population.
@@ -108,43 +111,48 @@ class Population(object):
         :param pop_synth: Population synth
         :type pop_synth: Optional[Dict[str, Any]]
         """
-        self._luminosities = luminosities  # type: ArrayLike
 
-        self._distances = distances  # type: ArrayLike
-        self._known_distances = known_distances  # type: ArrayLike
-        self._known_distance_idx = known_distance_idx  # type: ArrayLike
-        self._unknown_distance_idx = unknown_distance_idx  # type: ArrayLike
+        self._protected_names: List[str] = []
 
-        self._theta = theta  # type: ArrayLike
-        self._phi = phi  # type: ArrayLike
+        self._luminosities: SimulatedVariable = SimulatedVariable(
+            luminosities, luminosities, selection
+        )
+
+        self._distances: SimulatedVariable = SimulatedVariable(
+            distances, distances, selection
+        )
+
+        self._known_distances: ArrayLike = known_distances
+        self._known_distance_idx: ArrayLike = known_distance_idx
+        self._unknown_distance_idx: ArrayLike = unknown_distance_idx
+
+        self._theta: SimulatedVariable = SimulatedVariable(
+            theta, theta, selection
+        )
+        self._phi: SimulatedVariable = SimulatedVariable(phi, phi, selection)
 
         assert len(known_distances) + len(unknown_distance_idx) == sum(
             selection
         ), "the distances are not the correct size"
 
-        # latent fluxes
-        self._fluxes = fluxes  # type: ArrayLike
+        # fluxes
 
-        # observed fluxes
-        self._flux_obs = flux_obs  # type: ArrayLike
-        self._selection = selection  # type: ArrayLike
-        self._flux_sigma = flux_sigma  # type: float
+        self._fluxes: SimulatedVariable = SimulatedVariable(
+            flux_obs, fluxes, selection
+        )
+
+        self._selection: ArrayLike = selection
+        self._flux_sigma: float = flux_sigma
+
+        self._r_max: float = r_max
+        self._seed: int = seed
+        self._n_model: int = n_model
+
+        self._name: str = name
 
-        self._r_max = r_max  # type: float
-        self._seed = seed  # type: int
-        self._n_model = n_model  # type: int
-        self._name = name  # type: str
         self._spatial_form = spatial_form
         self._lf_form = lf_form
 
-        self._flux_selected = flux_obs[selection]  # type: ArrayLike
-        self._distance_selected = distances[selection]  # type: ArrayLike
-        self._luminosity_selected = luminosities[selection]  # type: ArrayLike
-
-        self._flux_hidden = flux_obs[~selection]  # type: ArrayLike
-        self._distance_hidden = distances[~selection]  # type: ArrayLike
-        self._luminosity_hidden = luminosities[~selection]  # type: ArrayLike
-
         self._lf_params = lf_params
         self._spatial_params = spatial_params
 
@@ -154,14 +162,22 @@ class Population(object):
 
         self._graph = graph
 
-        self._n_objects = len(selection)  # type: int
-        self._n_detections = sum(self._selection)  # type: int
-        self._n_non_detections = (
-            self._n_objects - self._n_detections
-        )  # type: int
+        self._n_objects: int = len(selection)
+        self._n_detections: int = sum(self._selection)
+        self._n_non_detections: int = self._n_objects - self._n_detections
 
         self._pop_synth: Optional[Dict[str, Any]] = pop_synth
 
+        if probability is not None:
+
+            self._probability: Optional[SimulatedVariable] = SimulatedVariable(
+                probability, probability, selection
+            )
+
+        else:
+
+            self._probability = None
+
         if self._n_detections == 0:
 
             self._no_detection = True
@@ -175,10 +191,14 @@ class Population(object):
         if auxiliary_quantities is not None:
 
             for k, v in auxiliary_quantities.items():
-
-                setattr(self, k, v["true_values"])
-                setattr(self, "%s_obs" % k, v["obs_values"])
-                setattr(self, "%s_selected" % k, v["obs_values"][selection])
+                setattr(
+                    self,
+                    k,
+                    SimulatedVariable(
+                        v["obs_values"], v["true_values"], selection
+                    ),
+                )
+                self._protected_names.append(k)
 
         self._auxiliary_quantities = auxiliary_quantities
 
@@ -188,6 +208,19 @@ class Population(object):
 
                 assert len(v) == n_model
 
+    def __setattr__(self, name, value):
+
+        # dont allow setting of aux properties
+
+        if name == "_protected_names":
+            object.__setattr__(self, name, value)
+
+        elif name in self._protected_names:
+            raise AttributeError('Denied.')
+
+        else:
+            object.__setattr__(self, name, value)
+
     @property
     def graph(self):
         """
@@ -199,6 +232,10 @@ class Population(object):
 
         return self._graph
 
+    @property
+    def probability(self) -> Optional[SimulatedVariable]:
+        return self._probability
+
     @property
     def pop_synth(self) -> Dict[str, Any]:
         """
@@ -223,43 +260,54 @@ class Population(object):
         return self._flux_sigma
 
     @property
-    def theta(self) -> np.ndarray:
+    def theta(self) -> SimulatedVariable:
         """
         The polar angle of the objects
         """
         return self._theta
 
     @property
-    def phi(self) -> np.ndarray:
+    def phi(self) -> SimulatedVariable:
         """
         The phi angle of the objects
         """
         return self._phi
 
     @property
-    def dec(self) -> np.ndarray:
+    def dec(self) -> SimulatedVariable:
         """
         The declination of the objects
         """
         return 90 - np.rad2deg(self._theta)
 
     @property
-    def ra(self) -> np.ndarray:
+    def ra(self) -> SimulatedVariable:
         """
         The right ascension of the objects
         """
         return np.rad2deg(self._phi)
 
+    @property
+    def luminosities(self) -> SimulatedVariable:
+        """
+        the luminosities of the objects
+
+        :returns:
+
+        """
+
+        return self._luminosities
+
     @property
     def luminosities_latent(self) -> np.ndarray:
         """
         The true luminosities of the objects. These are always latent
         as one cannot directly observe them.
         """
-        return self._luminosities
+        return self._luminosities.latent
 
     @property
-    def distances(self) -> np.ndarray:
+    def distances(self) -> SimulatedVariable:
         """
         The distances to the objects
         """
@@ -280,12 +328,28 @@ class Population(object):
         """
         return self._selection
 
+    @property
+    def fluxes(self) -> SimulatedVariable:
+        """
+        the fluxes of the objects
+
+        :returns:
+
+        """
+
+        return self._fluxes
+
     @property
     def fluxes_latent(self) -> np.ndarray:
         """
         The latent fluxes of the objects
         """
-        return self._fluxes
+
+        msg = "This will be removed in future versions use fluxes.latent"
+
+        log.warning(msg)
+
+        return self._fluxes.latent
 
     @property
     def fluxes_observed(self) -> np.ndarray:
@@ -293,7 +357,12 @@ class Population(object):
         All of the observed fluxes, i.e.,
         scattered with error
         """
-        return self._flux_obs
+
+        msg = "This will be removed in future versions use x.fluxes"
+
+        log.warning(msg)
+
+        return self._fluxes
 
     @property
     def selected_fluxes_observed(self) -> np.ndarray:
@@ -301,7 +370,11 @@ class Population(object):
         The selected obs fluxes
         """
 
-        return self._flux_selected
+        msg = "This will be removed in future versions use x.fluxes.selected"
+
+        log.warning(msg)
+
+        return self._fluxes.selected
 
     @property
     def selected_fluxes_latent(self) -> np.ndarray:
@@ -309,7 +382,11 @@ class Population(object):
         The selected latent fluxes
         """
 
-        return self._fluxes[self._selection]
+        msg = "This will be removed in future versions use x.fluxes.selected.latent"
+
+        log.warning(msg)
+
+        return self._fluxes.selected.latent
 
     @property
     def selected_distances(self) -> np.ndarray:
@@ -317,7 +394,12 @@ class Population(object):
         The selected distances. Note, this is different than
         the KNOWN distances.
         """
-        return self._distance_selected
+
+        msg = "This will be removed in future versions use x.distances.selected"
+
+        log.warning(msg)
+
+        return self._distances.selected
 
     @property
     def hidden_fluxes_observed(self) -> np.ndarray:
@@ -325,7 +407,13 @@ class Population(object):
         The observed fluxes that are hidden by the selection
         """
 
-        return self._flux_hidden
+        msg = (
+            "This will be removed in future versions use x.fluxes.non_selected"
+        )
+
+        log.warning(msg)
+
+        return self._fluxes.non_selected
 
     @property
     def hidden_distances(self) -> np.ndarray:
@@ -333,7 +421,11 @@ class Population(object):
         The distances that are hidden by the selection
         """
 
-        return self._distance_hidden
+        msg = "This will be removed in future versions use x.distances.non_selected"
+
+        log.warning(msg)
+
+        return self._distances.non_selected
 
     @property
     def hidden_fluxes_latent(self) -> np.ndarray:
@@ -341,7 +433,11 @@ class Population(object):
         The latent fluxes that are hidden by the selection
         """
 
-        return self._fluxes[~self._selection]
+        msg = "This will be removed in future versions use x.distances.non_selected"
+
+        log.warning(msg)
+
+        return self._fluxes.non_selected.latent
 
     @property
     def hard_cut(self) -> bool:
@@ -416,16 +512,16 @@ class Population(object):
             N=self._n_detections,
             Nz=len(self._known_distances),
             Nnz=len(self._unknown_distance_idx),
-            z_obs=self._distance_selected,
+            z_obs=self._distances.selected,
             known_z_obs=self._known_distances,
             z_idx=self._known_distance_idx + 1,  # stan indexing
             z_nidx=self._unknown_distance_idx + 1,  # stan indexing
-            r_obs=self._distance_selected,
+            r_obs=self._distances.selected,
             known_r_obs=self._known_distances,
             r_idx=self._known_distance_idx + 1,  # stan indexing
             r_nidx=self._unknown_distance_idx + 1,  # stan indexing
-            log_flux_obs=np.log10(self._flux_selected),
-            flux_obs=self._flux_selected,
+            log_flux_obs=np.log10(self._fluxes.selected),
+            flux_obs=self._fluxes.selected.view(np.ndarray),
             flux_sigma=self._flux_sigma,
             z_max=self._r_max,
             r_max=self._r_max,
@@ -489,7 +585,9 @@ class Population(object):
 
         for k, v in self._spatial_params.items():
 
-            spatial_grp.create_dataset(k, data=np.array([v]), compression="lzf")
+            spatial_grp.create_dataset(
+                k, data=np.array([v]), compression="gzip"
+            )
 
         if self._lf_params is not None:
 
@@ -497,7 +595,9 @@ class Population(object):
 
             for k, v in self._lf_params.items():
 
-                lum_grp.create_dataset(k, data=np.array([v]), compression="lzf")
+                lum_grp.create_dataset(
+                    k, data=np.array([v]), compression="gzip"
+                )
 
             f.attrs["lf_form"] = np.string_(self._lf_form)
 
@@ -513,28 +613,33 @@ class Population(object):
         f.attrs["r_max"] = self._r_max
         f.attrs["seed"] = int(self._seed)
 
+        if self._probability is not None:
+            f.create_dataset(
+                "probabilty", data=self._probability, compression="gzip"
+            )
+
         f.create_dataset(
-            "luminosities", data=self._luminosities, compression="lzf"
+            "luminosities", data=self._luminosities, compression="gzip"
         )
-        f.create_dataset("distances", data=self._distances, compression="lzf")
+        f.create_dataset("distances", data=self._distances, compression="gzip")
         f.create_dataset(
-            "known_distances", data=self._known_distances, compression="lzf"
+            "known_distances", data=self._known_distances, compression="gzip"
         )
         f.create_dataset(
             "known_distance_idx",
             data=self._known_distance_idx,
-            compression="lzf",
+            compression="gzip",
         )
         f.create_dataset(
             "unknown_distance_idx",
             data=self._unknown_distance_idx,
-            compression="lzf",
+            compression="gzip",
         )
-        f.create_dataset("fluxes", data=self._fluxes, compression="lzf")
-        f.create_dataset("flux_obs", data=self._flux_obs, compression="lzf")
-        f.create_dataset("selection", data=self._selection, compression="lzf")
-        f.create_dataset("theta", data=self._theta, compression="lzf")
-        f.create_dataset("phi", data=self._phi, compression="lzf")
+        f.create_dataset("fluxes", data=self._fluxes.latent, compression="gzip")
+        f.create_dataset("flux_obs", data=self._fluxes, compression="gzip")
+        f.create_dataset("selection", data=self._selection, compression="gzip")
+        f.create_dataset("theta", data=self._theta, compression="gzip")
+        f.create_dataset("phi", data=self._phi, compression="gzip")
 
         aux_grp = f.create_group("auxiliary_quantities")
 
@@ -542,17 +647,17 @@ class Population(object):
 
             q_grp = aux_grp.create_group(k)
             q_grp.create_dataset(
-                "true_values", data=v["true_values"], compression="lzf"
+                "true_values", data=v["true_values"], compression="gzip"
             )
             q_grp.create_dataset(
-                "obs_values", data=v["obs_values"], compression="lzf"
+                "obs_values", data=v["obs_values"], compression="gzip"
             )
 
         model_grp = f.create_group("model_spaces")
 
         for k, v in self._model_spaces.items():
 
-            model_grp.create_dataset(k, data=v, compression="lzf")
+            model_grp.create_dataset(k, data=v, compression="gzip")
 
         # now store the truths
         recursively_save_dict_contents_to_group(f, "truth", self._truth)
@@ -649,12 +754,20 @@ class Population(object):
             known_distance_idx = (f["known_distance_idx"][()]).astype(int)
             unknown_distance_idx = (f["unknown_distance_idx"][()]).astype(int)
 
-        except AttributeError:
+        except KeyError:
 
             known_distances = None
             known_distance_idx = None
             unknown_distance_idx = None
 
+        try:
+
+            probability = f["probability"][()]
+
+        except KeyError:
+
+            probability = None
+
         fluxes = f["fluxes"][()]
         flux_obs = f["flux_obs"][()]
         selection = f["selection"][()]
@@ -709,6 +822,7 @@ class Population(object):
             theta=theta,
             phi=phi,
             pop_synth=pop_synth,
+            probability=probability,
         )
 
     def to_sub_population(self, observed: bool = True) -> "Population":
@@ -723,10 +837,19 @@ class Population(object):
         """
 
         if observed:
+
+            def _selector(x):
+
+                return x.selected
+
             selection = self._selection
 
         else:
 
+            def _selector(x):
+
+                return x.non_selected
+
             selection = ~self._selection
 
         if self._auxiliary_quantities is not None:
@@ -764,14 +887,22 @@ class Population(object):
 
                 itr += 1
 
+        if self._probability is not None:
+
+            probability = _selector(self._probability)
+
+        else:
+
+            probability = None
+
         return Population(
-            luminosities=self._luminosities[selection],
-            distances=self._distances[selection],
+            luminosities=_selector(self._luminosities),
+            distances=_selector(self._distances),
             known_distances=np.array(known_distances),
             known_distance_idx=np.array(known_distance_idx),
             unknown_distance_idx=np.array(unknown_distance_idx),
-            fluxes=self._fluxes[selection],
-            flux_obs=self._flux_obs[selection],
+            fluxes=_selector(self._fluxes).latent,
+            flux_obs=_selector(self._fluxes),
             selection=np.ones(sum(selection), dtype=bool),
             flux_sigma=self._flux_sigma,
             n_model=self._n_model,
@@ -786,8 +917,9 @@ class Population(object):
             auxiliary_quantities=new_aux,
             truth=self._truth,
             graph=self._graph,
-            theta=self._theta[selection],
-            phi=self._phi[selection],
+            theta=_selector(self._theta),
+            phi=_selector(self._phi),
+            probability=probability,
         )
 
     def display(self):
@@ -860,7 +992,7 @@ class Population(object):
         try:
 
             ax.set_ylim(
-                bottom=min([self._fluxes.min(), self._flux_selected.min()])
+                bottom=min([self._fluxes.min(), self._fluxes.selected.min()])
             )
 
         except ValueError:
@@ -900,8 +1032,8 @@ class Population(object):
             fig = ax.get_figure()
 
         ax.scatter(
-            self._distance_selected,
-            self._flux_selected,
+            self._distances.selected,
+            self._fluxes.selected,
             alpha=0.8,
             color=flux_color,
             edgecolors="none",
@@ -913,7 +1045,9 @@ class Population(object):
         # ax.set_xscale('log')
         ax.set_yscale("log")
 
-        ax.set_ylim(bottom=min([self._fluxes.min(), self._flux_selected.min()]))
+        ax.set_ylim(
+            bottom=min([self._fluxes.min(), self._fluxes.selected.min()])
+        )
         ax.set_xlim(right=self._r_max)
 
         ax.set_xlabel("distance")
@@ -954,8 +1088,8 @@ class Population(object):
         if (with_arrows) and (not self._no_detection):
             for start, stop, z in zip(
                 self._fluxes[self._selection],
-                self._flux_selected,
-                self._distance_selected,
+                self._fluxes.selected,
+                self._distances.selected,
             ):
 
                 x = z
@@ -999,14 +1133,14 @@ class Population(object):
             fig = ax.get_figure()
 
         ax.scatter(
-            self._distance_selected,
-            self._luminosity_selected,
+            self._distances.selected,
+            self._luminosities.selected,
             s=5,
             color=obs_color,
         )
         ax.scatter(
-            self._distance_hidden,
-            self._luminosity_hidden,
+            self._distances.non_selected,
+            self._luminosities.non_selected,
             s=5,
             color=true_color,
         )
@@ -1087,8 +1221,8 @@ class Population(object):
         phi = self._phi[self._selection]
 
         fig = self._display_sphere(
-            self._flux_selected,
-            self._distance_selected,
+            self._fluxes.selected,
+            self._distances.selected,
             theta=theta,
             phi=phi,
             cmap=cmap,
@@ -1114,12 +1248,12 @@ class Population(object):
         **kwargs,
     ):
 
-        theta = self._theta[~self._selection]
-        phi = self._phi[~self._selection]
+        theta = self._theta.non_selected
+        phi = self._phi.non_selected
 
         fig = self._display_sphere(
-            self._flux_hidden,
-            self._distance_hidden,
+            self._fluxes.non_selected,
+            self._distances.non_selected,
             theta=theta,
             phi=phi,
             cmap=cmap,
@@ -1190,7 +1324,7 @@ class Population(object):
             label="Total Pop.",
         )
         ax.hist(
-            self._distance_selected,
+            self._distances.selected,
             bins=bins,
             #            facecolor=blue,
             #            edgecolor=blue_highlight,
