@@ -1,13 +1,17 @@
+from popsynth.distribution import LuminosityDistribution
 from popsynth.distributions.cosmological_distribution import (  # MergerDistribution,
-    SFRDistribution, ZPowerCosmoDistribution,
+    SFRDistribution,
+    ZPowerCosmoDistribution,
 )
 from popsynth.distributions.spherical_distribution import (
     ConstantSphericalDistribution,
     ZPowerSphericalDistribution,
 )
-from popsynth.distribution import LuminosityDistribution
-from popsynth.distributions.spiral_galaxy_distribution import SpiralGalaxyDistribution
+from popsynth.distributions.spiral_galaxy_distribution import (
+    SpiralGalaxyDistribution,
+)
 from popsynth.population_synth import PopulationSynth
+
 """
 Create a range of spatial populations that can
 be expanded with luminosity distributions.
