@@ -8,7 +8,10 @@ import colorama
 from colorama import Back, Fore, Style
 
 from popsynth.utils.configuration import popsynth_config
-from popsynth.utils.package_data import get_path_of_log_dir, get_path_of_log_file
+from popsynth.utils.package_data import (
+    get_path_of_log_dir,
+    get_path_of_log_file,
+)
 
 colorama.deinit()
 colorama.init(strip=False)
@@ -19,10 +22,10 @@ class ColoredFormatter(logging.Formatter):
     """
     Colored log formatter.
     """
-    def __init__(self,
-                 *args,
-                 colors: Optional[Dict[str, str]] = None,
-                 **kwargs) -> None:
+
+    def __init__(
+        self, *args, colors: Optional[Dict[str, str]] = None, **kwargs
+    ) -> None:
         """Initialize the formatter with specified format strings."""
 
         super().__init__(*args, **kwargs)
@@ -49,7 +52,8 @@ class MyFilter(object):
 # now create the developer handler that rotates every day and keeps
 # 10 days worth of backup
 popsynth_dev_log_handler = handlers.TimedRotatingFileHandler(
-    get_path_of_log_file("dev.log"), when="D", interval=1, backupCount=10)
+    get_path_of_log_file("dev.log"), when="D", interval=1, backupCount=10
+)
 
 # lots of info written out
 
@@ -64,13 +68,15 @@ popsynth_dev_log_handler.setLevel(logging.DEBUG)
 # now set up the usr log which will save the info
 
 popsynth_usr_log_handler = handlers.TimedRotatingFileHandler(
-    get_path_of_log_file("usr.log"), when="D", interval=1, backupCount=10)
+    get_path_of_log_file("usr.log"), when="D", interval=1, backupCount=10
+)
 
 popsynth_usr_log_handler.setLevel(popsynth_config["logging"]["file"]["level"])
 
 # lots of info written out
-_usr_formatter = logging.Formatter("%(asctime)s | %(levelname)s | %(message)s",
-                                   datefmt="%Y-%m-%d %H:%M:%S")
+_usr_formatter = logging.Formatter(
+    "%(asctime)s | %(levelname)s | %(message)s", datefmt="%Y-%m-%d %H:%M:%S"
+)
 
 popsynth_usr_log_handler.setFormatter(_usr_formatter)
 
@@ -92,7 +98,8 @@ _console_formatter = ColoredFormatter(
 popsynth_console_log_handler = logging.StreamHandler(sys.stdout)
 popsynth_console_log_handler.setFormatter(_console_formatter)
 popsynth_console_log_handler.setLevel(
-    popsynth_config["logging"]["console"]["level"])
+    popsynth_config["logging"]["console"]["level"]
+)
 
 warning_filter = MyFilter(logging.WARNING)
 
@@ -115,19 +122,25 @@ class LoggingState(object):
         # store their current states
 
         self.popsynth_usr_log_handler_state = popsynth_usr_log_handler.level
-        self.popsynth_console_log_handler_state = popsynth_console_log_handler.level
+        self.popsynth_console_log_handler_state = (
+            popsynth_console_log_handler.level
+        )
 
     def _store_state(self):
 
         self.popsynth_usr_log_handler_state = popsynth_usr_log_handler.level
-        self.popsynth_console_log_handler_state = popsynth_console_log_handler.level
+        self.popsynth_console_log_handler_state = (
+            popsynth_console_log_handler.level
+        )
 
     def restore_last_state(self):
 
         self.popsynth_usr_log_handler.setLevel(
-            self.popsynth_usr_log_handler_state)
+            self.popsynth_usr_log_handler_state
+        )
         self.popsynth_console_log_handler.setLevel(
-            self.popsynth_console_log_handler_state)
+            self.popsynth_console_log_handler_state
+        )
 
     def silence_logs(self):
 
